@@ -21,10 +21,23 @@
 #ifndef HEADER_APP_GLOM
 #define HEADER_APP_GLOM
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
+//TODO: Remove this when maemomm's gtkmm has been updated. 7th September 2009.
+#ifdef GLOM_ENABLE_MAEMO
+//Because earlier versions of gtkmm/enums.h did not include this, so  
+//GTKMM_MAEMO_EXTENSIONS_ENABLED was not defined, 
+//leading to a compiler error in hildonmm/button.h
+#include <gtkmmconfig.h>
+#include <gtkmm/enums.h>
+
+#include <hildonmm/app-menu.h>
+#include <glom/navigation/maemo/pickerbutton_table.h>
+#endif //GLOM_ENABLE_MAEMO
+
 #include <glom/bakery/app_withdoc_gtk.h>
-#include "frame_glom.h"
+#include <glom/frame_glom.h>
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 
 //Avoid including the header here:
@@ -40,11 +53,11 @@ namespace Glom
 
 class Window_Translations;
 
-class App_Glom : public GlomBakery::App_WithDoc_Gtk
+class Application : public GlomBakery::App_WithDoc_Gtk
 {
 public:
-  App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-  virtual ~App_Glom();
+  Application(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
+  virtual ~Application();
 
   virtual bool init(const Glib::ustring& document_uri = Glib::ustring()); //override
 
@@ -52,7 +65,11 @@ public:
   //virtual void statusbar_clear();
 
   /// Get the UIManager so we can merge new menus in.
+  #ifndef GLOM_ENABLE_MAEMO
   Glib::RefPtr<Gtk::UIManager> get_ui_manager();
+  #else
+  Hildon::AppMenu* get_maemo_appmenu();
+  #endif //GLOM_ENABLE_MAEMO
 
   /** Changes the mode to Data mode, as if the user had selected the Data Mode menu item.
    */
@@ -78,30 +95,50 @@ public:
   void fill_menu_reports(const Glib::ustring& table_name);
   void fill_menu_print_layouts(const Glib::ustring& table_name);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void do_menu_developer_fields(Gtk::Window& parent, const Glib::ustring table_name);
   void do_menu_developer_relationships(Gtk::Window& parent, const Glib::ustring table_name);
+#endif //GLOM_ENABLE_CLIENT_ONLY
 
   ///Whether to show the generated SQL queries on stdout, for debugging.
   bool get_show_sql_debug() const;
 
   ///Whether to show the generated SQL queries on stdout, for debugging.
   void set_show_sql_debug(bool val = true);
+  
+  void show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value);
+  void show_table_list(const Glib::ustring& table_name);
+  
+  static Application* get_application();
 
-  static App_Glom* get_application();
+protected:
+  virtual void ui_warning_load_failed(int failure_code = 0); //Override.
 
 private:
   virtual void init_layout(); //override.
-  virtual void init_menus_file(); //override.
   virtual void init_menus(); //override.
-  virtual void init_menus_help(); //override
   virtual void init_toolbars(); //override
   virtual void init_create_document(); //override
   virtual bool on_document_load(); //override.
   virtual void on_document_close(); //override.
+  virtual void update_window_title(); //override.
+
+#ifndef GLOM_ENABLE_MAEMO
+  virtual void init_menus_file(); //override.
+  virtual void init_menus_help(); //override
+#endif //GLOM_ENABLE_MAEMO
 
   bool offer_new_or_existing();
 
+#ifndef GLOM_ENABLE_MAEMO
   void on_menu_help_contents();
+#endif //GLOM_ENABLE_MAEMO
+
+  /** Check that the file's hosting mode is supported by this build and 
+   * tell the user if necessary.
+   */
+  bool check_document_hosting_mode_is_supported(Document* document);
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void existing_or_new_new();
 
@@ -138,8 +175,6 @@ private:
   Glib::ustring ui_file_select_open_with_browse(bool& browsed, EpcServiceInfo*& browsed_server, Glib::ustring& browsed_service_name, const Glib::ustring& starting_folder_uri = Glib::ustring());
 #endif // !G_OS_WIN32
 
-  virtual void on_menu_file_open(); //overridden.
-  virtual void on_menu_file_close(); //override.
   virtual void document_history_add(const Glib::ustring& file_uri); //overridden.
 
   virtual void new_instance(const Glib::ustring& uri = Glib::ustring()); //Override
@@ -167,6 +202,13 @@ private:
   Glib::RefPtr<Gtk::ToggleAction> m_action_show_layout_toolbar;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+#ifdef GLOM_ENABLE_MAEMO
+  Hildon::AppMenu m_maemo_appmenu;
+  PickerButton_Table m_appmenu_button_table;
+
+  void on_appmenu_button_table_value_changed();
+#endif //GLOM_ENABLE_MAEMO
+
   Glib::RefPtr<Gtk::ToggleAction> m_toggleaction_network_shared;
   sigc::connection m_connection_toggleaction_network_shared;
 
@@ -192,6 +234,8 @@ private:
   Glib::ustring m_ui_save_extra_newdb_title;
 
   Document::HostingMode m_ui_save_extra_newdb_hosting_mode;
+
+  Gtk::MessageDialog* m_avahi_progress_dialog;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   // This is set to the URI of an example file that is loaded to be able to
@@ -204,8 +248,6 @@ private:
   //so we can use them again when connecting directly to the database:
   Glib::ustring m_temp_username, m_temp_password;
 
-  Gtk::MessageDialog* m_avahi_progress_dialog;
-  
   bool m_show_sql_debug;
 };
 
