@@ -37,6 +37,13 @@ class PyGlomRecord
 public:
   PyGlomRecord();
   ~PyGlomRecord();
+  
+  /* Prevent python code from changing data in the database via this object.
+   * For instance, this should be used in a field calculation, 
+   * though changing data would be OK from a script.
+   * This is not exposed via Python.
+   */
+  void set_read_only();
 
   std::string get_table_name() const;
 
@@ -48,12 +55,13 @@ public:
   //[] notation:
   long len() const;
   boost::python::object getitem(const boost::python::object& item);
+  void setitem(const boost::python::object& /* key */, const boost::python::object& /* value */);
 
 public:
-  //PyObject* m_fields_dict; //Dictionary (map) of field names (string) to field values (Gnome::Gda::Value).
-  //PyGObject* m_py_gda_connection; //"derived" from PyObject.
   Document* m_document;
   Glib::ustring m_table_name;
+  sharedptr<const Field> m_key_field;
+  Gnome::Gda::Value m_key_field_value;
 
   boost::python::object m_related; //Actually a PyGlomRelated
 
@@ -62,9 +70,18 @@ public:
   type_map_field_values m_map_field_values;
 
   Glib::RefPtr<Gnome::Gda::Connection> m_connection;
+  
+private:
+  bool m_read_only;
 };
 
-void PyGlomRecord_SetFields(PyGlomRecord* self, const PyGlomRecord::type_map_field_values& field_values, Document* document, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection);
+void PyGlomRecord_SetFields(PyGlomRecord* self,
+  const PyGlomRecord::type_map_field_values& field_values,
+  Document* document,
+  const Glib::ustring& table_name,
+  const sharedptr<const Field>& key_field,
+  const Gnome::Gda::Value& key_field_value,
+  const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection);
 
 } //namespace Glom
 
