@@ -200,7 +200,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
   if(m_child)
   {
     //Use the text formatting:
-    apply_formatting(*m_child, field->get_formatting_used());
+    apply_formatting(*m_child, field);
     
     bool child_added = false; //Don't use an extra container unless necessary.
 
@@ -446,80 +446,6 @@ void DataWidget::set_editable(bool editable)
   }
 }
 
-/*
-void DataWidget::setup_menu()
-{
-  m_refActionGroup->add(m_refContextLayout,
-    sigc::mem_fun(*this, &DataWidget::on_menupopup_activate_layout) );
-
-  m_refActionGroup->add(m_refContextLayoutProperties,
-    sigc::mem_fun(*this, &DataWidget::on_menupopup_activate_layout_properties) );
-
-  m_refActionGroup->add(m_refContextAddField,
-    sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), LayoutWidgetBase::TYPE_FIELD ) );
-
-  m_refActionGroup->add(m_refContextAddRelatedRecords,
-    sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), LayoutWidgetBase::TYPE_PORTAL ) );
-
-  m_refActionGroup->add(m_refContextAddGroup,
-    sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), LayoutWidgetBase::TYPE_GROUP ) );
-
-  //TODO: This does not work until this widget is in a container in the window:s
-  App_Glom* pApp = get_application();
-  if(pApp)
-  {
-    pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
-    pApp->add_developer_action(m_refContextLayoutProperties); //So that it can be disabled when not in developer mode.
-    pApp->add_developer_action(m_refContextAddField);
-    pApp->add_developer_action(m_refContextAddRelatedRecords);
-    pApp->add_developer_action(m_refContextAddGroup);
-
-    pApp->update_userlevel_ui(); //Update our action's sensitivity. 
-  }
-
-  m_refUIManager = Gtk::UIManager::create();
-
-  m_refUIManager->insert_action_group(m_refActionGroup);
-
-  //TODO: add_accel_group(m_refUIManager->get_accel_group());
-
-  try
-  {
-    Glib::ustring ui_info = 
-        "<ui>"
-        "  <popup name='ContextMenu'>"
-        "    <menuitem action='ContextLayout'/>"
-        "    <menuitem action='ContextLayoutProperties'/>"
-        "    <menuitem action='ContextAddField'/>"
-        "    <menuitem action='ContextAddRelatedRecords'/>"
-        "    <menuitem action='ContextAddGroup'/>"
-        "  </popup>"
-        "</ui>";
-
-    m_refUIManager->add_ui_from_string(ui_info);
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << "building menus failed: " <<  ex.what();
-  }
-
-  //Get the menu:
-  m_pMenuPopup = dynamic_cast<Gtk::Menu*>( m_refUIManager->get_widget("/ContextMenu") ); 
-  if(!m_pMenuPopup)
-    g_warning("menu not found");
-
-
-  if(pApp)
-  {
-    const bool sensitive = pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER;
-    m_refContextLayout->set_sensitive(sensitive);
-    m_refContextAddField->set_sensitive(sensitive);
-    m_refContextAddRelatedRecords->set_sensitive(sensitive);
-    m_refContextAddGroup->set_sensitive(sensitive);
-  }
-}
-*/
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 bool DataWidget::on_button_press_event(GdkEventButton *event)
 {
@@ -527,7 +453,7 @@ bool DataWidget::on_button_press_event(GdkEventButton *event)
 
   //Enable/Disable items.
   //We did this earlier, but get_application is more likely to work now:
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -565,7 +491,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
   return offer_field_list(table_name, start_field, get_document(), get_application());
 }
 
-sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, App_Glom* app)
+sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, Application* app)
 {
   sharedptr<LayoutItem_Field> result;
 
@@ -699,12 +625,12 @@ void DataWidget::on_child_user_requested_layout()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-App_Glom* DataWidget::get_application()
+Application* DataWidget::get_application()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<App_Glom*>(pWindow);
+  return dynamic_cast<Application*>(pWindow);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
