@@ -24,19 +24,24 @@
 #include <gtkmm.h>
 #include <libglom/data_structure/layout/layoutitem_field.h>
 #include <libgdamm.h>
-#include "glom_db_treemodel.h"
-#include <libglom/document/document_glom.h>
+#include <glom/utility_widgets/db_adddel/glom_db_treemodel.h>
+#include <libglom/document/document.h>
 #include <glom/base_db_table_data.h>
 
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/pannable-area.h>
+#include <hildonmm/touch-selector.h>
+#endif //GLOM_ENABLE_MAEMO
+
 #include <vector>
 #include <map>
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
 class DbAddDelColumnInfo
 {
@@ -48,8 +53,8 @@ public:
   sharedptr<LayoutItem> m_item;
 
   //For fields with choices:
-  typedef std::vector<Glib::ustring> type_vecStrings;
-  type_vecStrings m_choices;
+  typedef std::vector<Glib::ustring> type_vec_strings;
+  type_vec_strings m_choices;
 
   bool m_editable;
   bool m_visible;
@@ -178,28 +183,23 @@ public:
 
   sharedptr<const LayoutItem_Field> get_column_field(guint column_index) const;
 
-  typedef DbAddDelColumnInfo::type_vecStrings type_vecStrings;
+  typedef DbAddDelColumnInfo::type_vec_strings type_vec_strings;
 
   /** Retrieves the column order, even after they have been reordered by the user.
    * @result a vector of column_id. These column_ids were provided in the call to add_column().
    */
-  type_vecStrings get_columns_order() const;
+  type_vec_strings get_columns_order() const;
 
   void remove_all_columns();
-  //virtual void set_columns_count(guint count);
-  //virtual void set_column_title(guint col, const Glib::ustring& strText);
-  void set_column_width(guint col, guint width);
 
   /// For popup cells.
-  void set_column_choices(guint col, const type_vecStrings& vecStrings);
+  void set_column_choices(guint col, const type_vec_strings& vecStrings);
 
   void construct_specified_columns(); //Delay actual use of set_column_*() stuff until this method is called.
 
   bool refresh_from_database();
   bool refresh_from_database_blank();
 
-  void set_show_column_titles(bool bVal = true);
-
   Gtk::TreeModel::iterator get_row(const Gnome::Gda::Value& key);
 
   void finish_editing(); //Closes active edit controls and commits the data to the cell.
@@ -213,8 +213,6 @@ public:
   Glib::RefPtr<Gtk::TreeModel> get_model();
   Glib::RefPtr<const Gtk::TreeModel> get_model() const;
 
-  void set_rules_hint(bool val = true);
-
   //Signals:
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -258,6 +256,12 @@ public:
   virtual Gtk::TreeModel::iterator get_last_row() const;
 
   virtual void set_open_button_title(const Glib::ustring& title);
+  
+  
+  /** Add a new row to the list, for the user to enter record details,
+   * adding the generated primary key if necessary.
+   */
+  bool start_new_record();
 
 private:
   
@@ -289,6 +293,9 @@ private:
 protected:
   virtual void setup_menu();
 
+  /// A common handler for the edit button, the context menu, etc.
+  void do_user_requested_edit();
+
 private:
   virtual Gnome::Gda::Value treeview_get_key(const Gtk::TreeModel::iterator& row) const;
 
@@ -296,35 +303,54 @@ private:
   //virtual Gtk::TreeModel::iterator get_next_available_row_with_add_if_necessary();
 
   //Signal handlers:
+  #ifdef GLOM_ENABLE_MAEMO
+  void treeviewcolumn_on_cell_data(const Gtk::TreeModel::iterator& iter, int model_column_index, int data_model_column_index);
+  void on_maemo_touchselector_changed(int column);
+  #else
   void treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, int model_column_index, int data_model_column_index);
+  #endif //GLOM_ENABLE_MAEMO
+
 
   //TODO: Remove virtuals after checking that there are no method overrides:
+  #ifndef GLOM_ENABLE_MAEMO
   virtual void on_treeview_cell_edited(const Glib::ustring& path_string, const Glib::ustring& new_text, int model_column_index, int data_model_column_index);
   virtual void on_treeview_cell_edited_bool(const Glib::ustring& path_string, int model_column_index, int data_model_column_index);
 
-  virtual bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
-  virtual void on_treeview_columns_changed();
+  bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
+  void on_treeview_columns_changed();
 
   virtual bool on_button_press_event_Popup(GdkEventButton* event);
+  virtual void on_treeview_button_press_event(GdkEventButton* event);
 
 protected:
   void on_MenuPopup_activate_Edit();
   void on_MenuPopup_activate_Add();
   void on_MenuPopup_activate_Delete();
-
 private:
+  #endif //GLOM_ENABLE_MAEMO
+
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_MenuPopup_activate_layout();
 #endif
 
-  virtual void on_treeview_button_press_event(GdkEventButton* event);
-
+  #ifndef GLOM_ENABLE_MAEMO
   virtual bool on_treeview_columnheader_button_press_event(GdkEventButton* event);
   virtual void on_treeview_column_clicked(int model_column_index);
   void on_treeview_column_resized(int model_column_index, DbTreeViewColumnGlom* view_column);
   virtual void on_cell_button_clicked(const Gtk::TreeModel::Path& path);
   void on_cell_layout_button_clicked(const Gtk::TreeModel::Path& path, int model_column_index);
+  #endif //GLOM_ENABLE_MAEMO
+
+  #ifdef GLOM_ENABLE_MAEMO
+  void on_touch_selector_changed(int model_column_index);
+  #endif
+
+  #ifdef GLOM_ENABLE_MAEMO
+  /// Get the single column, adding it if necessary.
+  Glib::RefPtr<Hildon::TouchSelectorColumn> touch_selector_get_column();
+  Glib::RefPtr<const Hildon::TouchSelectorColumn> touch_selector_get_column() const;
+  #endif
 
 #ifdef GLOM_ENABLE_CLIENT_ONLY 
   // Don't name it on_style_changed, otherwise we would override a virtual
@@ -344,7 +370,7 @@ private:
   guint get_count_hidden_system_columns() const;
 
   //The column_id is extra information that we can use later to discover what the column shows, even when columns have been reordered.
-  guint treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, int model_column_index, int data_model_column_index);
+  guint treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, int model_column_index, int data_model_column_index, bool expand);
 
   /** Show a model that gives a visual hint to the developer,
    * when he has not yet specified fields to show.
@@ -355,16 +381,21 @@ private:
   int get_fixed_cell_height();
 
   //TODO: Remove this and use AppGlom::get_application() instead?
-  App_Glom* get_application();
+  Application* get_application();
 
-  static void apply_formatting(Gtk::CellRenderer* renderer, const FieldFormatting& formatting);
+  static void apply_formatting(Gtk::CellRenderer* renderer, const sharedptr<const LayoutItem_WithFormatting>& layout_item);
 
   typedef Gtk::VBox type_base;
 
   //Member widgets:
+  #ifdef GLOM_ENABLE_MAEMO
+  Hildon::TouchSelector m_TreeView;
+  #else
   Gtk::ScrolledWindow m_ScrolledWindow;
-
   Gtk::TreeView m_TreeView;
+  #endif
+
+
   Gtk::TreeModel::ColumnRecord m_ColumnRecord;
 
   //typedef Gtk::ListStore type_model_store;
@@ -384,11 +415,13 @@ protected:
   Glib::ustring m_open_button_title; //Allow us to change "Open" to "Select".
 
 private:
+  #ifndef GLOM_ENABLE_MAEMO
   //TODO: Avoid repeating these in so many widgets:
   Gtk::Menu* m_pMenuPopup;
   Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup;
   Glib::RefPtr<Gtk::UIManager> m_refUIManager;
   Glib::RefPtr<Gtk::Action> m_refContextEdit, m_refContextAdd, m_refContextDelete;
+  #endif //GLOM_ENABLE_MAEMO
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Glib::RefPtr<Gtk::Action> m_refContextLayout;
@@ -399,8 +432,8 @@ private:
   bool m_bPreventUserSignals;
   bool m_bIgnoreTreeViewSignals;
 
-  type_vecStrings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
-
+  type_vec_strings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
+  
 protected:
   bool m_allow_add;
   bool m_allow_delete;
@@ -416,7 +449,10 @@ private:
   bool m_columns_ready;
   bool m_allow_view;
   bool m_allow_view_details;
+
+  #ifndef GLOM_ENABLE_MAEMO
   Gtk::TreeViewColumn* m_treeviewcolumn_button;
+  #endif
 
   //Signals:
   type_signal_user_requested_edit m_signal_user_requested_edit;
@@ -471,12 +507,13 @@ private:
   Glib::RefPtr<Gtk::ListStore> m_model_hint;
 
   int m_fixed_cell_height;
-    
-    
+  
 private:
   
+  /// Discover the right-most text column, so we can make it expand.
+  bool get_column_to_expand(guint& column_to_expand) const;
+  
   //TODO_refactor: Give these better names, and document them:
-  bool start_new_record();
   void user_changed(const Gtk::TreeModel::iterator& row, guint col);
   void user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator&  /* rowEnd TODO */);
 
