@@ -22,6 +22,7 @@
 #include <glibmm/i18n.h>
 #include <glom/application.h>
 #include <glom/utility_widgets/textviewglom.h>
+#include <glom/utility_widgets/labelglom.h>
 
 namespace Glom
 {
@@ -54,7 +55,7 @@ sharedptr<LayoutItem> LayoutWidgetBase::get_layout_item()
   return m_pLayoutItem;
 }
 
-App_Glom* LayoutWidgetBase::get_application() const
+Application* LayoutWidgetBase::get_application() const
 {
   return 0; //override to implement.
 }
@@ -90,13 +91,17 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const sharedptr<con
   Gtk::Widget* widget_to_change = &widget;
 
   Gtk::Button* button = dynamic_cast<Gtk::Button*>(&widget);
+  LabelGlom* labelglom = dynamic_cast<LabelGlom*>(&widget);
   if(button)
     widget_to_change = button->get_child();
-
-  Glom::TextViewGlom* textview = dynamic_cast<Glom::TextViewGlom*>(&widget);
-  if(textview)
-    widget_to_change = textview->get_textview();
-
+  else
+  {
+    TextViewGlom* textview = dynamic_cast<TextViewGlom*>(&widget);
+    if(textview)
+      widget_to_change = textview->get_textview();
+    else if(labelglom)
+      widget_to_change = labelglom->get_label();
+  }
 
   if(!layout_item)
     return;
@@ -108,7 +113,18 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const sharedptr<con
   Gtk::Misc* misc = dynamic_cast<Gtk::Misc*>(widget_to_change);
   if(misc)
     misc->set_alignment(x_align);
-
+    
+  //Set justification on labels:
+  //Assume that people want left/right justification of multi-line text if they chose 
+  //left/right alignment of the text itself.
+  {
+    Gtk::Label* label = dynamic_cast<Gtk::Label*>(widget_to_change);
+    if(label)
+    {    
+      const Gtk::Justification justification = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? Gtk::JUSTIFY_LEFT : Gtk::JUSTIFY_RIGHT);
+      label->set_justify(justification);
+    }
+  }
 
   const FieldFormatting& formatting = layout_item->get_formatting_used();
 
@@ -119,15 +135,41 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const sharedptr<con
     widget_to_change->modify_font( Pango::FontDescription(font_desc) );
   }
 
-  // "text" is the text color. "fg" doesn't seem to have any effect:
+  
   const Glib::ustring fg = formatting.get_text_format_color_foreground();
   if(!fg.empty())
+  {
+    // "text" is the text color. (Works for GtkEntry and GtkTextView, 
+    // for which modify_fg() doesn't seem to have any effect.
     widget_to_change->modify_text(Gtk::STATE_NORMAL, Gdk::Color(fg));
+    
+    // This works for GtkLabel, for which modify_text() does not.
+    widget_to_change->modify_fg(Gtk::STATE_NORMAL, Gdk::Color(fg));
+  }
+
 
-  // "base" is the background color. "bg" seems to change the border:
   const Glib::ustring bg = formatting.get_text_format_color_background();
   if(!bg.empty())
-    widget_to_change->modify_base(Gtk::STATE_NORMAL, Gdk::Color(bg));
+  {
+    if(!labelglom && !button)
+    {
+      // "base" is the background color for GtkEntry. "bg" seems to change the border:
+      widget_to_change->modify_base(Gtk::STATE_NORMAL, Gdk::Color(bg));
+    }
+    //According to the gtk_widget_modify_base() documentation, 
+    //a GtkLabel can only have a background color by, for instance, placing it 
+    //in a GtkEventBox. Luckily LabelGlom is actually derived from EventBox.
+    else if(labelglom)
+    {
+      //label->modify_base(Gtk::STATE_NORMAL, Gdk::Color("bg"));
+      labelglom->modify_bg(Gtk::STATE_NORMAL, Gdk::Color(bg));
+    }
+    else if(button)
+    {
+      //button->modify_base(Gtk::STATE_NORMAL, Gdk::Color("bg"));
+      button->modify_bg(Gtk::STATE_NORMAL, Gdk::Color(bg));
+    }
+  }
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
