@@ -23,12 +23,12 @@
 
 #include <gtkmm.h>
 #include "notebookglom.h"
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
 class NotebookLabelGlom
 : public Gtk::EventBox
@@ -43,7 +43,7 @@ public:
 private:
   void init();
 
-  virtual App_Glom* get_application();
+  virtual Application* get_application();
     
   Gtk::Label m_label;
   NotebookGlom* m_notebook;
