@@ -21,15 +21,16 @@
 #include "config.h" // For GLOM_ENABLE_MAEMO
 
 #include "xsl_utils.h"
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
-#include <glom/libglom/data_structure/glomconversions.h>
-#include "frame_glom.h"
+#include <libglom/connectionpool.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/frame_glom.h>
 #include <libxml++/libxml++.h>
 #include <libxslt/transform.h>
 //#include <libexslt/exslt.h> //For exsltRegisterAll().
 #include <giomm.h>
 #include <glibmm/i18n.h>
+#include <gtk/gtk.h>
 
 #include <sstream> //For stringstream
 
@@ -41,6 +42,26 @@
 #include <iostream>   // for cout, endl
 #include <iomanip>
 
+// For ShellExecute:
+#ifdef G_OS_WIN32
+# include <windows.h>
+#endif
+
+namespace
+{
+  Glib::ustring get_xslt_file(const Glib::ustring& xsl_file)
+  {
+#ifdef G_OS_WIN32
+    gchar* directory = g_win32_get_package_installation_directory_of_module(0);
+    Glib::ustring xsltdir = Glib::build_filename(Glib::build_filename(directory,
+        "share" G_DIR_SEPARATOR_S "glom" G_DIR_SEPARATOR_S "xslt"), xsl_file);
+    g_free(directory);
+    return xsltdir;
+#else
+    return Glib::build_filename(GLOM_PKGDATADIR G_DIR_SEPARATOR_S "xslt", xsl_file);
+#endif
+  }
+}
 
 namespace Glom
 {
@@ -48,15 +69,15 @@ namespace Glom
 void GlomXslUtils::transform_and_open(const xmlpp::Document& xml_document, const Glib::ustring& xsl_file_path, Gtk::Window* parent_window)
 {
   //Use libxslt to convert the XML to HTML:
-  Glib::ustring result = xslt_process(xml_document, GLOM_XSLTDIR + xsl_file_path);
+  Glib::ustring result = xslt_process(xml_document, get_xslt_file(xsl_file_path));
   std::cout << "After xslt: " << result << std::endl;
 
   //Save it to a temporary file and show it in a browser:
   //TODO: This actually shows it in gedit.
-  const Glib::ustring temp_uri = "file:///tmp/glom_printout.html";
-  std::cout << "temp_uri=" << temp_uri << std::endl;
+  const Glib::ustring temp_path = Glib::get_tmp_dir() + "/glom_printout.html";
+  std::cout << "temp_path=" << temp_path << std::endl;
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(temp_uri);
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_path(temp_path);
   Glib::RefPtr<Gio::FileOutputStream> stream;
 
   //Create the file if it does not already exist:
@@ -77,11 +98,17 @@ void GlomXslUtils::transform_and_open(const xmlpp::Document& xml_document, const
   catch(const Gio::Error& ex)
   {
 #else
-  std::auto_ptr<Gio::Error> error;
-  stream.create(error);
-  if(error.get() != NULL)
+  std::auto_ptr<Glib::Error> error;
+  if (file->query_exists())
+  {
+    stream = file->replace("" /* etag */, false /*make_backup*/, Gio::FILE_CREATE_NONE, error);
+  }
+  else
+  {
+    stream = file->create_file(Gio::FILE_CREATE_NONE, error);
+  }
+  if(error.get())
   {
-    const Gio::Error& ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
     return; // false; // print_error(ex, output_uri_string);
@@ -99,9 +126,8 @@ void GlomXslUtils::transform_and_open(const xmlpp::Document& xml_document, const
   {
 #else
   bytes_written = stream->write(result.data(), result_bytes, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
-    Gio::Error& ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
     return; // false; //print_error(ex, output_uri_string);
@@ -115,14 +141,20 @@ void GlomXslUtils::transform_and_open(const xmlpp::Document& xml_document, const
   if(parent_window)
     Frame_Glom::show_ok_dialog(_("Report Finished"), _("The report will now be opened in your web browser."), *parent_window, Gtk::MESSAGE_INFO);
 
+#ifdef G_OS_WIN32
+  // gtk_show_uri doesn't seem to work on Win32, at least not for local files
+  // We use Windows API instead.
+  // TODO: Check it again and file a bug if necessary.
+  ShellExecute(0, "open", file->get_path().c_str(), 0, 0, SW_SHOW);
+#else
   //Use the GNOME browser:
   GError* gerror = 0;
-  // g_app_info_launch_default_for_uri seems not to be wrapped by giomm
-  if(!g_app_info_launch_default_for_uri(temp_uri.c_str(), NULL, &gerror))
+  if(!gtk_show_uri(0 /* screen */, file->get_uri().c_str(), GDK_CURRENT_TIME, &gerror))
   {
-    std::cerr << "Error while calling g_app_info_launch_default_for_uri(): " << gerror->message << std::endl;
+    std::cerr << "Error while calling gtk_show_uri(): " << gerror->message << std::endl;
     g_error_free(gerror);
   }
+#endif
 }
 
 Glib::ustring GlomXslUtils::xslt_process(const xmlpp::Document& xml_document, const std::string& filepath_xslt)
